==> tfmodelserver-1.0.6.dev1-py3-none-any.whl: tfmodelserver/resolver.py <==
""" Resolver """
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import numpy as np
from PIL import Image
from io import BytesIO
import requests

from absl.logging import debug, error, fatal, info, warn


def imdecode(b, target_shape=None):
    img = Image.open(BytesIO(b))

    if target_shape is not None:
        img.resize(target_shape)

    return np.asarray(img)[..., :3]


class BaseResolver:
    def __init__(self, name: str, required=False):
        self._name = name
        self._required = required

    @property
    def name(self):
        return self._name

    @property
    def required(self):
        return self._required

    def __call__(self, *args, **kwargs):
        raise NotImplementedError


class FileResolver(BaseResolver):
    def __init__(self, name: str, required=False, fn=None):
        BaseResolver.__init__(self, name, required=required)

        def identity(b):
            return b

        self._fn = fn or identity

    def __call__(self, files, **kwargs):
        if self.required and self.name not in files:
            raise KeyError('`{}` is required'.format(self.name))
        return files.get(self.name, type=lambda f: self._fn(f.read()))


class ImageFileResolver(FileResolver):
    def __init__(self, name: str, required=False, target_shape=None):
        FileResolver.__init__(self, name, required=required)

        self._target_shape = target_shape

    @property
    def target_shape(self):
        return self._target_shape

    def __call__(self, files, **kwargs):
        b = FileResolver.__call__(self, files, **kwargs)

        if b is None:
            return None

        decoded = imdecode(b, target_shape=self.target_shape)

        if decoded is None:
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return decoded, b


class FormResolver(BaseResolver):
    def __init__(self, name: str, type=None, default=None, required=False):
        BaseResolver.__init__(self, name, required=required)
        self._default = default
        self._type = type

    def __call__(self, form, **kwargs):
        if self.required and self.name not in form:
            raise KeyError('`{}` is required'.format(self.name))
        return form.get(self.name, default=self._default, type=self._type)


class URLResolver(FormResolver):
    def __init__(self, name: str, required=False):
        FormResolver.__init__(self, name, type=str, required=required)

    def __call__(self, form, **kwargs):
        url = FormResolver.__call__(self, form, **kwargs)

        if url is None:
            return None

        try:
            res = requests.get(url)
        except Exception as e:
            info(e)
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return res.content


class ImageURLResolver(URLResolver):
    def __init__(self, name: str, required=False, target_shape=None):
        URLResolver.__init__(self, name, required=required)

        self._target_shape = target_shape

    @property
    def target_shape(self):
        return self._target_shape

    def __call__(self, form, **kwargs):
        b = URLResolver.__call__(self, form, **kwargs)

        if b is None:
            return None

        decoded = imdecode(b, target_shape=self.target_shape)

        if decoded is None:
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return decoded, b

==> tfmodelserver-1.0.7.dev4-py3-none-any.whl: tfmodelserver/resolver.py <==
""" Resolver """
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import numpy as np
from PIL import Image
from io import BytesIO
import requests

from absl.logging import debug, error, fatal, info, warn


def imdecode(b, target_shape=None):
    img = Image.open(BytesIO(b)).convert('RGB')

    if target_shape is not None:
        img = img.resize(target_shape)

    return np.asarray(img)[..., :3]


class BaseResolver:
    def __init__(self, name: str, required=False):
        self._name = name
        self._required = required

    @property
    def name(self):
        return self._name

    @property
    def required(self):
        return self._required

    def __call__(self, *args, **kwargs):
        raise NotImplementedError


class FileResolver(BaseResolver):
    def __init__(self, name: str, required=False, fn=None):
        BaseResolver.__init__(self, name, required=required)

        def identity(b):
            return b

        self._fn = fn or identity

    def __call__(self, files, **kwargs):
        if self.required and self.name not in files:
            raise KeyError('`{}` is required'.format(self.name))
        return files.get(self.name, type=lambda f: self._fn(f.read()))


class ImageFileResolver(FileResolver):
    def __init__(self, name: str, required=False, target_shape=None):
        FileResolver.__init__(self, name, required=required)

        self._target_shape = target_shape

    @property
    def target_shape(self):
        return self._target_shape

    def __call__(self, files, **kwargs):
        b = FileResolver.__call__(self, files, **kwargs)

        if b is None:
            return None

        decoded = imdecode(b, target_shape=self.target_shape)

        if decoded is None:
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return decoded, b


class FormResolver(BaseResolver):
    def __init__(self, name: str, type=None, default=None, required=False):
        BaseResolver.__init__(self, name, required=required)
        self._default = default
        self._type = type

    def __call__(self, form, **kwargs):
        if self.required and self.name not in form:
            raise KeyError('`{}` is required'.format(self.name))
        return form.get(self.name, default=self._default, type=self._type)


class URLResolver(FormResolver):
    def __init__(self, name: str, required=False):
        FormResolver.__init__(self, name, type=str, required=required)

    def __call__(self, form, **kwargs):
        url = FormResolver.__call__(self, form, **kwargs)

        if url is None:
            return None

        try:
            res = requests.get(url)
        except Exception as e:
            info(e)
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return res.content


class ImageURLResolver(URLResolver):
    def __init__(self, name: str, required=False, target_shape=None):
        URLResolver.__init__(self, name, required=required)

        self._target_shape = target_shape

    @property
    def target_shape(self):
        return self._target_shape

    def __call__(self, form, **kwargs):
        b = URLResolver.__call__(self, form, **kwargs)

        if b is None:
            return None

        decoded = imdecode(b, target_shape=self.target_shape)

        if decoded is None:
            raise ValueError('Invalid data on `{}`'.format(self.name))

        return decoded, b
